@@ -12,9 +12,9 @@ val drop_position : t -> t
 
 val of_lexbuf : Lexing.lexbuf -> t
 
-val to_sexp : t -> Sexp.t
+val to_dyn : t -> Dyn.t
 
-val sexp_of_position_no_file : Lexing.position -> Sexp.t
+val dyn_of_position_no_file : Lexing.position -> Dyn.t
 
 val equal : t -> t -> bool
 
@@ -26,11 +26,4 @@ val pp_file_colon_line : Format.formatter -> t -> unit
 
 val print : Format.formatter -> t -> unit
 
-val pp_file_excerpt
-  : context_lines:int
-  -> max_lines_to_print_in_full:int
-  -> Format.formatter
-  -> t
-  -> unit
-
 val on_same_line : t -> t -> bool
